/*!
 * use-textarea v1.5.1
 * A combined api for editable html and textarea
 * (c) 2022-2023 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
this.useTextarea = (function (vueDemi) {
    'use strict';

    typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
      var e = new Error(message);
      return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
    };

    /**
     * Determine if it is running on the browser side
     *
     * @returns boolean
     */
    var inBrowser = typeof window !== 'undefined';

    function useTextarea(element) {
      if (!inBrowser) return;
      if (!element) {
        console.error('element is required');
        return;
      }
      var el = vueDemi.isRef(element) ? element : vueDemi.ref(element);
      var insert = function insert(data) {
        if (!el.value) {
          console.error('the element is null');
          return;
        }
        if (document.selection) {
          // IE
          var sel = document.selection.createRange();
          sel.text = data;
        } else if (typeof el.value.selectionStart === 'number' && typeof el.value.selectionEnd === 'number') {
          var startPos = el.value.selectionStart;
          var endPos = el.value.selectionEnd;
          var tmpStr = el.value.value;
          var curPos_1 = startPos;
          el.value.value = tmpStr.substring(0, startPos) + data + tmpStr.substring(endPos, tmpStr.length);
          curPos_1 += data.length;
          setTimeout(function () {
            el.value.selectionStart = el.value.selectionEnd = curPos_1;
          }, 0);
        } else {
          el.value.value += data;
        }
      };
      var moveToEnd = function moveToEnd() {
        if (!el.value) {
          console.error('the element is null');
          return;
        }
        el.value.focus();
        var len = el.value.value.length;
        if (document.selection) {
          var sel = el.createTextRange();
          sel.moveStart('character', len);
          sel.collapse();
          sel.select();
        } else if (typeof el.value.selectionStart == 'number' && typeof el.value.selectionEnd == 'number') {
          el.value.selectionStart = el.value.selectionEnd = len;
        }
      };
      return {
        el: el,
        insert: insert,
        moveToEnd: moveToEnd
      };
    }

    return useTextarea;

})(VueDemi);
